require('ggplot2')

d_attest_ipv8 <- read.csv('ipv8_attest.csv')
d_attest_ipv8_range <- read.csv('ipv8_attest_range.csv')
d_attest_ipv8_big <- read.csv('ipv8_attest_big.csv')
d_attest_ipv8_irma <- read.csv('ipv8_attest_irma.csv')
d_attest_indy <- read.csv('ipv8_attest_indy.csv')
d_attest_uport <- read.csv('ipv8_attest_uport.csv')
d_attest_jolocom <- read.csv('ipv8_attest_jolocom.csv')

d_verify_ipv8 <- read.csv('ipv8_verify.csv')
d_verify_ipv8_range <- read.csv('ipv8_verify_range.csv')
d_verify_ipv8_big <- read.csv('ipv8_verify_big.csv')
d_verify_ipv8_irma <- read.csv('ipv8_verify_irma.csv')
d_verify_indy <- read.csv('ipv8_verify_indy.csv')
d_verify_uport <- read.csv('ipv8_verify_uport.csv')
d_verify_jolocom <- read.csv('ipv8_verify_jolocom.csv')

dataset_count <- 7
dataset_names <- c("TCID-1024", "TCID-4096", "TCID-PB", "TCID-IRMA", "Hyperledger Indy", "uPort", "Jolocom")
d_attest_list <- list(d_attest_ipv8, d_attest_ipv8_big, d_attest_ipv8_range, d_attest_ipv8_irma, d_attest_indy, d_attest_uport, d_attest_jolocom)
d_verify_list <- list(d_verify_ipv8, d_verify_ipv8_big, d_verify_ipv8_range, d_verify_ipv8_irma, d_verify_indy, d_verify_uport, d_verify_jolocom)

dfa <- data.frame(matrix(ncol = dataset_count, nrow = 0))
colnames(dfa) <- c("name", "latency", "action")

for (i in 1:dataset_count){
    df_dsa <- data.frame(name=dataset_names[i],
                         latency=d_attest_list[[i]]$latency,
                         traffic=d_attest_list[[i]]$traffic/1000,
                         cpu=d_attest_list[[i]]$cpu,
                         action="enrollment")
    df_dsv <- data.frame(name=dataset_names[i],
                         latency=d_verify_list[[i]]$latency,
                         traffic=d_verify_list[[i]]$traffic/1000,
                         cpu=d_verify_list[[i]]$cpu,
                         action="verification")
    dfa <- rbind(dfa, df_dsa)
    dfa <- rbind(dfa, df_dsv)
}

ggplot(dfa,
       aes(x = name, y = latency, fill = name, color = name, group = name)) +
       geom_boxplot() +
       facet_wrap(~action) +
       scale_x_discrete(limits=dataset_names) +
       ylab("latency (s)") +
       scale_colour_hue(l = 40) +
       theme_bw() + 
       theme(text=element_text(family="serif"), legend.position = "none",
             axis.text.x = element_text(angle = 60, vjust = 1.0, hjust=1),
             axis.title.x = element_blank())
ggsave("perf_latency.pdf", width=4, height=3)
dev.off()

ggplot(dfa,
       aes(x = name, y = traffic, fill = name, color = name, group = name)) +
       geom_boxplot() +
       facet_wrap(~action) +
       scale_x_discrete(limits=dataset_names) +
       ylab("traffic (kB)") +
       scale_colour_hue(l = 40) +
       theme_bw() + 
       theme(text=element_text(family="serif"), legend.position = "none",
             axis.text.x = element_text(angle = 60, vjust = 1.0, hjust=1),
             axis.title.x = element_blank())
ggsave("perf_traffic.pdf", width=4, height=3)
dev.off()

ggplot(dfa,
       aes(x = name, y = cpu, fill = name, color = name, group = name)) +
       geom_boxplot() +
       facet_wrap(~action) +
       scale_x_discrete(limits=dataset_names) +
       ylab("cpu usage (%)") +
       scale_colour_hue(l = 40) +
       theme_bw() + 
       theme(text=element_text(family="serif"), legend.position = "none",
             axis.text.x = element_text(angle = 60, vjust = 1.0, hjust=1),
             axis.title.x = element_blank())
ggsave("perf_cpu.pdf", width=4, height=3)
dev.off()